Морфологический анализатор pymorphy2
====================================

pymorphy2_ написан на языке Python (работает под 2.7 и 3.5+). Он умеет:

1. приводить слово к нормальной форме (например, "люди -> человек",
   или "гулял -> гулять").

2. ставить слово в нужную форму. Например, ставить слово
   во множественное число, менять падеж слова и т.д.

3. возвращать грамматическую информацию о слове (число, род,
   падеж, часть речи и т.д.)

При работе используется словарь OpenCorpora_; для незнакомых слов
строятся гипотезы. Библиотека достаточно быстрая: в настоящий
момент скорость работы - от нескольких тыс слов/сек до > 100тыс слов/сек
(в зависимости от выполняемой операции, интерпретатора
и установленных пакетов); потребление памяти - 10...20Мб;
полностью :ref:`поддерживается <char-substitutes>` буква ё.

Лицензия - MIT. Если вы используете pymorphy2 в научной работе,
см. также раздел :ref:`citing`.

Содержание
----------

.. toctree::
   :maxdepth: 2

   user/index
   internals/index
   misc/index
   misc/citing
   glossary

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`


Исходный код - на github_. Если заметили ошибку, то пишите
в `баг-трекер`_. Для обсуждения есть `гугл-группа`_; если есть какие-то
вопросы - пишите туда.


.. _github: https://github.com/kmike/pymorphy2
.. _баг-трекер: https://github.com/kmike/pymorphy2/issues
.. _гугл-группа: https://groups.google.com/forum/?fromgroups#!forum/pymorphy
.. _pymorphy2: https://github.com/kmike/pymorphy2
.. _pymorphy: https://bitbucket.org/kmike/pymorphy/
.. _OpenCorpora: http://opencorpora.org

